package org.jeecg.modules.system.app.controller;

import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.system.query.QueryRuleEnum;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.system.app.entity.AppInsure;
import org.jeecg.modules.system.app.service.IAppInsureService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.v3.oas.annotations.tags.Tag;
import io.swagger.v3.oas.annotations.Operation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;
 /**
 * @Description: 保险表
 * @Author: jeecg-boot
 * @Date:   2025-07-03
 * @Version: V1.0
 */
@Tag(name="保险表")
@RestController
@RequestMapping("/app/appInsure")
@Slf4j
public class AppInsureController extends JeecgController<AppInsure, IAppInsureService> {
	@Autowired
	private IAppInsureService appInsureService;
	
	/**
	 * 分页列表查询
	 *
	 * @param appInsure
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "保险表-分页列表查询")
	@Operation(summary="保险表-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<AppInsure>> queryPageList(AppInsure appInsure,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {


        QueryWrapper<AppInsure> queryWrapper = QueryGenerator.initQueryWrapper(appInsure, req.getParameterMap());
		Page<AppInsure> page = new Page<AppInsure>(pageNo, pageSize);
		IPage<AppInsure> pageList = appInsureService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param appInsure
	 * @return
	 */
	@AutoLog(value = "保险表-添加")
	@Operation(summary="保险表-添加")
	@RequiresPermissions("org.jeecg.modules.app:nm_insure:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody AppInsure appInsure) {
		appInsureService.save(appInsure);

		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param appInsure
	 * @return
	 */
	@AutoLog(value = "保险表-编辑")
	@Operation(summary="保险表-编辑")
	@RequiresPermissions("org.jeecg.modules.app:nm_insure:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody AppInsure appInsure) {
		appInsureService.updateById(appInsure);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "保险表-通过id删除")
	@Operation(summary="保险表-通过id删除")
	@RequiresPermissions("org.jeecg.modules.app:nm_insure:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		appInsureService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "保险表-批量删除")
	@Operation(summary="保险表-批量删除")
	@RequiresPermissions("org.jeecg.modules.app:nm_insure:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.appInsureService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "保险表-通过id查询")
	@Operation(summary="保险表-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<AppInsure> queryById(@RequestParam(name="id",required=true) String id) {
		AppInsure appInsure = appInsureService.getById(id);
		if(appInsure==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(appInsure);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param appInsure
    */
    @RequiresPermissions("org.jeecg.modules.app:nm_insure:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, AppInsure appInsure) {
        return super.exportXls(request, appInsure, AppInsure.class, "保险表");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("org.jeecg.modules.app:nm_insure:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, AppInsure.class);
    }

}
