package org.jeecg.modules.system.app.controller;

import org.jeecg.common.api.vo.Result;

import com.baomidou.mybatisplus.core.metadata.IPage;
import lombok.extern.slf4j.Slf4j;

import org.jeecg.modules.system.app.dto.*;
import org.jeecg.modules.system.app.entity.AppSitePlace;
import org.jeecg.modules.system.app.service.IAppSitePlaceService;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import io.swagger.v3.oas.annotations.tags.Tag;
import io.swagger.v3.oas.annotations.Operation;
import org.jeecg.common.aspect.annotation.AutoLog;

/**
 * @Description: 商户场所表
 * @Author: jeecg-boot
 * @Date:   2025-07-09
 * @Version: V1.0
 */
@Tag(name="商户场所表")
@RestController
@RequestMapping("/app/appSitePlace")
@Slf4j
public class AppSitePlaceController extends JeecgController<AppSitePlace, IAppSitePlaceService> {
	@Autowired
	private IAppSitePlaceService appSitePlaceService;
	
	/**
	 * 分页列表查询
	 *
	 * @param appSitePlace
	 * @return
	 */
	//@AutoLog(value = "商户场所表-分页列表查询")
	@Operation(summary="商户场所学校、体育馆包场-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<AppSitePlaceCuDTO>> queryPageList(AppSitePlacePageDTO appSitePlace) {
		return Result.OK(appSitePlaceService.querySchoolPage(appSitePlace));
	}
	/**
	 * 分页列表查询
	 *
	 * @param appSitePlace
	 * @return
	 */
	//@AutoLog(value = "商户场所表-分页列表查询")
	@Operation(summary="商户场所无固定场-分页列表查询")
	@GetMapping(value = "/queryUnfixedPageList")
	public Result<IPage<AppSitePlaceUnfixedDTO>> queryUnfixedPageList(AppSitePlaceUnfixedPageDTO appSitePlace) {
		return Result.OK(appSitePlaceService.queryUnfixedPage(appSitePlace));
	}
	
	/**
	 *   添加
	 *
	 * @param appSitePlace
	 * @return
	 */
	@AutoLog(value = "商户场所学校-添加")
	@Operation(summary="商户场所学校-添加")
//	@RequiresPermissions("org.jeecg.modules.system.app:nm_site_place:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody AppSitePlaceSchoolDTO appSitePlace) {
		appSitePlaceService.saveSchool(appSitePlace);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param appSitePlace
	 * @return
	 */
	@AutoLog(value = "商户场所学校-编辑")
	@Operation(summary="商户场所学校-编辑")
//	@RequiresPermissions("org.jeecg.modules.system.app:nm_site_place:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody AppSitePlaceSchoolDTO appSitePlace) {
		appSitePlaceService.editSchool(appSitePlace);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "商户场所学校-通过id删除")
	@Operation(summary="商户场所学校-通过id删除")
//	@RequiresPermissions("org.jeecg.modules.system.app:nm_site_place:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		appSitePlaceService.removeById(id);
		return Result.OK("删除成功!");
	}

	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "商户场所表-通过id查询")
	@Operation(summary="商户场所学校通过id查询")
	@GetMapping(value = "/queryById")
	public Result<AppSitePlaceSchoolDTO> queryById(@RequestParam(name="id",required=true) String id) {
		return Result.OK(appSitePlaceService.querySchoolById( id));
	}

//    /**
//    * 导出excel
//    *
//    * @param request
//    * @param appSitePlace
//    */
//    @RequiresPermissions("org.jeecg.modules.system.app:nm_site_place:exportXls")
//    @RequestMapping(value = "/exportXls")
//    public ModelAndView exportXls(HttpServletRequest request, AppSitePlace appSitePlace) {
//        return super.exportXls(request, appSitePlace, AppSitePlace.class, "商户场所表");
//    }
//
//    /**
//      * 通过excel导入数据
//    *
//    * @param request
//    * @param response
//    * @return
//    */
//    @RequiresPermissions("org.jeecg.modules.system.app:nm_site_place:importExcel")
//    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
//    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
//        return super.importExcel(request, response, AppSitePlace.class);
//    }

}
