package org.jeecg.modules.system.app.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.apache.commons.lang3.StringUtils;
import org.apache.shiro.SecurityUtils;
import org.jeecg.common.exception.JeecgBootException;
import org.jeecg.common.system.vo.LoginUser;
import org.jeecg.modules.system.app.dto.*;
import org.jeecg.modules.system.app.entity.AppCategory;
import org.jeecg.modules.system.app.entity.AppSite;
import org.jeecg.modules.system.app.entity.AppSitePlace;
import org.jeecg.modules.system.app.entity.AppSitePriceRules;
import org.jeecg.modules.system.app.enums.SitePlaceTypeEnum;
import org.jeecg.modules.system.app.mapper.AppCategoryMapper;
import org.jeecg.modules.system.app.mapper.AppSiteMapper;
import org.jeecg.modules.system.app.mapper.AppSitePlaceMapper;
import org.jeecg.modules.system.app.mapper.AppSitePriceRulesMapper;
import org.jeecg.modules.system.app.service.IAppSitePlaceService;
import org.jeecg.modules.system.app.utils.TimeRangeFinder;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.*;
import java.util.stream.Collectors;

import static org.jeecg.common.constant.CommonConstant.SC_INTERNAL_SERVER_ERROR_500;

/**
 * @Description: 商户场所表
 * @Author: jeecg-boot
 * @Date: 2025-07-09
 * @Version: V1.0
 */
@Service
public class AppSitePlaceServiceImpl extends ServiceImpl<AppSitePlaceMapper, AppSitePlace> implements IAppSitePlaceService {
    @Resource
    private AppSitePriceRulesMapper appSitePriceRulesMapper;
    @Resource
    private AppSiteMapper appSiteMapper;
    @Resource
    private AppCategoryMapper appCategoryMapper;

    //学校 一对多

    @Override
    @Transactional(rollbackFor = Exception.class)
    public Boolean saveSchool(AppSitePlaceSchoolDTO placeDTO) {
        AppSitePlaceCuDTO appSitePlaceCuDTO = placeDTO.getAppSitePlaceCuDTO();
        LoginUser sysUser = (LoginUser) SecurityUtils.getSubject().getPrincipal();
        if (null == appSitePlaceCuDTO.getSiteId())
            throw new JeecgBootException("商户补充信息id不能为空", SC_INTERNAL_SERVER_ERROR_500);
        AppSite site = appSiteMapper.selectById(appSitePlaceCuDTO.getSiteId());
        AppSitePlace appSitePlace = new AppSitePlace();
        BeanUtils.copyProperties(appSitePlaceCuDTO, appSitePlace);
        appSitePlace.setOrgCode(site.getOrgCode());
        appSitePlace.setTenantId(site.getTenantId());
        appSitePlace.setSiteId(site.getId());
        //时间段提取拼接
        List<AppSiteRuleDTO> siteRuleDTOS = placeDTO.getSiteRuleDTOS();

        List<String>  teachingDay= new ArrayList<>() ;
        List<String>   noTeachingDay= new ArrayList<>() ;
        if (!siteRuleDTOS.isEmpty()) {
            siteRuleDTOS.forEach(dto -> {
                if (dto.getIsTeaching() == 0) {
                    teachingDay.add(dto.getStartTime() + "-"+dto.getEndTime());
                } else {
                    noTeachingDay.add(dto.getStartTime() + "-"+dto.getEndTime());
                }
            });
        }
        site.setTeachingDay(String.join(",", teachingDay));
        site.setNoTeachingDay(String.join(",", noTeachingDay));
        int updateById = appSiteMapper.updateById(site);
        if (updateById < 1) {
            throw new JeecgBootException("学校补充信息更新失败");
        }
        int insert = baseMapper.insert(appSitePlace);
        if (insert < 1) {
            throw new JeecgBootException("学校场所信息保存失败");
        }
        siteRuleDTOS.forEach(rule -> {
            AppSitePriceRules appSitePriceRules = new AppSitePriceRules();
            BeanUtils.copyProperties(rule, appSitePriceRules);
            appSitePriceRules.setSitePlaceId(appSitePlace.getId());
            appSitePriceRules.setOrgCode(appSitePlace.getOrgCode());
            appSitePriceRules.setTenantId(appSitePlace.getTenantId());
            int savePriceResult = appSitePriceRulesMapper.insert(appSitePriceRules);
            if (savePriceResult < 1) {
                throw new JeecgBootException("场所价格规则保存失败", SC_INTERNAL_SERVER_ERROR_500);
            }
        });

        return Boolean.TRUE;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public Boolean editSchool(AppSitePlaceSchoolDTO placeDTO) {
        AppSitePlaceCuDTO appSitePlaceCuDTO = placeDTO.getAppSitePlaceCuDTO();
        LoginUser sysUser = (LoginUser) SecurityUtils.getSubject().getPrincipal();
        if (null == appSitePlaceCuDTO.getSiteId())
            throw new JeecgBootException("商户补充信息id不能为空", SC_INTERNAL_SERVER_ERROR_500);
        AppSite site = appSiteMapper.selectById(appSitePlaceCuDTO.getSiteId());
        AppSitePlace dbPlace = baseMapper.selectById(appSitePlaceCuDTO.getSiteId());
        if (null == dbPlace) throw new JeecgBootException("数据不存在", SC_INTERNAL_SERVER_ERROR_500);
        //部门校验
//        checkPermission(dbPlace, sysUser);
        AppSitePlace appSitePlace = new AppSitePlace();
        BeanUtils.copyProperties(appSitePlaceCuDTO, appSitePlace);
        //不许更改项赋值
        appSitePlace.setOrgCode(site.getOrgCode());
        appSitePlace.setTenantId(site.getTenantId());
        appSitePlace.setSiteId(site.getId());
        int update = baseMapper.updateById(appSitePlace);
        if (update < 1) {
            throw new JeecgBootException("商户场所保存失败");
        }
        List<AppSitePriceRules> dbRulesList = appSitePriceRulesMapper.selectList(Wrappers.<AppSitePriceRules>lambdaQuery()
                .eq(AppSitePriceRules::getSitePlaceId, appSitePlace.getId()));
        List<AppSiteRuleDTO> siteRuleDTOS = placeDTO.getSiteRuleDTOS();
        //删除
        List<AppSitePriceRules> deleteList = dbRulesList.stream().filter(
                dbRule -> dbRule.getId() != null && siteRuleDTOS.stream().noneMatch(rule -> dbRule.getId().equals(rule.getId()))).collect(Collectors.toList());
        deleteList.forEach(
                dbRule -> {
                    int deleteResult = appSitePriceRulesMapper.deleteById(dbRule.getId());
                    if (deleteResult < 1) {
                        throw new JeecgBootException("场所价格规则删除失败");
                    }
                }
        );
        //保存
        List<AppSitePriceRules> addList = siteRuleDTOS.stream().filter(rule -> rule.getId() == null).map(ruleDTO -> {
            AppSitePriceRules appSitePriceRules = new AppSitePriceRules();
            BeanUtils.copyProperties(ruleDTO, appSitePriceRules);
            appSitePriceRules.setOrgCode(appSitePlace.getOrgCode());
            appSitePriceRules.setTenantId(appSitePlace.getTenantId());
            appSitePriceRules.setSitePlaceId(appSitePlace.getId());
            return appSitePriceRules;
        }).collect(Collectors.toList());
        addList.forEach(appSitePriceRules -> {
            int saveResult = appSitePriceRulesMapper.insert(appSitePriceRules);
            if (saveResult < 1) {
                throw new JeecgBootException("场所价格规则保存失败", SC_INTERNAL_SERVER_ERROR_500);
            }
        });
        //更新
        List<AppSitePriceRules> updateList = siteRuleDTOS.stream().filter(
                rule -> rule.getId() != null && dbRulesList.stream().anyMatch(
                        dbRule -> dbRule.getId().equals(rule.getId()))).map(ruleDto -> {
            AppSitePriceRules appSitePriceRules = new AppSitePriceRules();
            BeanUtils.copyProperties(ruleDto, appSitePriceRules);
            appSitePriceRules.setSitePlaceId(appSitePlace.getId());
            appSitePriceRules.setOrgCode(appSitePlace.getOrgCode());
            appSitePriceRules.setTenantId(appSitePlace.getTenantId());
            return appSitePriceRules;
        }).collect(Collectors.toList());
        updateList.forEach(rule -> {
            int updateById = appSitePriceRulesMapper.updateById(rule);
            if (updateById < 1) {
                throw new JeecgBootException("场所价格规则更新失败", SC_INTERNAL_SERVER_ERROR_500);
            }
        });
        return Boolean.TRUE;
    }


    @Override
    @Transactional(rollbackFor = Exception.class)
    public AppSitePlaceSchoolDTO querySchoolById(String id) {
        AppSitePlace appSitePlace = baseMapper.selectById(id);
        if (null == appSitePlace) throw new JeecgBootException("数据不存在", SC_INTERNAL_SERVER_ERROR_500);
        AppSitePlaceCuDTO appSitePlaceCuDTO = new AppSitePlaceCuDTO();
        BeanUtils.copyProperties(appSitePlace, appSitePlaceCuDTO);
        List<AppSiteRuleDTO> collect = appSitePriceRulesMapper.selectList(Wrappers.<AppSitePriceRules>lambdaQuery()
                .eq(AppSitePriceRules::getSitePlaceId, appSitePlace.getId())).stream().map(
                appSitePriceRules -> {
                    AppSiteRuleDTO appSiteRuleDTO = new AppSiteRuleDTO();
                    BeanUtils.copyProperties(appSitePriceRules, appSiteRuleDTO);
                    return appSiteRuleDTO;
                }).collect(Collectors.toList());

        return new AppSitePlaceSchoolDTO(appSitePlaceCuDTO, collect);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public Boolean deleteSchoolById(String id) {
        AppSitePlace dbPlace = baseMapper.selectById(id);
        if (null == dbPlace) throw new JeecgBootException("未找到对应数据", SC_INTERNAL_SERVER_ERROR_500);
        LoginUser sysUser = (LoginUser) SecurityUtils.getSubject().getPrincipal();
//        checkPermission(dbPlace,sysUser);
        int deleteById = baseMapper.deleteById(id);
        if (deleteById < 1) throw new JeecgBootException("删除失败", SC_INTERNAL_SERVER_ERROR_500);
        int deletePriceResult = appSitePriceRulesMapper.delete(Wrappers.<AppSitePriceRules>lambdaQuery().eq(AppSitePriceRules::getSitePlaceId, id));
        if (deletePriceResult < 1) throw new JeecgBootException("场地价格规则删除失败", SC_INTERNAL_SERVER_ERROR_500);
        return Boolean.TRUE;
    }

    @Override
    public IPage<AppSitePlaceCuDTO> querySchoolPage(AppSitePlacePageDTO dto) {
        if (null == dto.getType()) throw new JeecgBootException("请选择类型", SC_INTERNAL_SERVER_ERROR_500);
        LoginUser loginUser = (LoginUser) SecurityUtils.getSubject().getPrincipal();
        Page<AppSitePlace> page = new Page<>(dto.getPageNum(), dto.getPageSize());
        LambdaQueryWrapper<AppSitePlace> wrapper = Wrappers.<AppSitePlace>lambdaQuery().eq(AppSitePlace::getType, dto.getType())
                .like(StringUtils.isNotBlank(dto.getName()), AppSitePlace::getName, dto.getName());
//                .eq(AppSitePlace::getOrgCode, loginUser.getOrgCode());
        IPage<AppSitePlace> resultPage = baseMapper.selectPage(page, wrapper);
        return resultPage.convert(record -> {
            AppSitePlaceCuDTO cuDTO = new AppSitePlaceCuDTO();
            BeanUtils.copyProperties(record, cuDTO);
            return cuDTO;
        });
    }

    // 无固定场
    @Override
    @Transactional(rollbackFor = Exception.class)
    public Boolean addUnfixed(AppSitePlaceUnfixedDTO unsetDTO) {
        if (null == unsetDTO.getSiteId()) throw new JeecgBootException("请选择商户门店", SC_INTERNAL_SERVER_ERROR_500);
        LoginUser sysUser = (LoginUser) SecurityUtils.getSubject().getPrincipal();
        AppSite site = appSiteMapper.selectById(unsetDTO.getSiteId());
        AppSitePlace appSitePlace = new AppSitePlace();
        BeanUtils.copyProperties(unsetDTO, appSitePlace);
        appSitePlace.setType(SitePlaceTypeEnum.UNFIXED.getCode());
        appSitePlace.setOrgCode(site.getOrgCode());
        appSitePlace.setTenantId(site.getTenantId());
        int insert = baseMapper.insert(appSitePlace);
        if (insert < 1) throw new JeecgBootException("无固定场添加失败", SC_INTERNAL_SERVER_ERROR_500);
        AppSitePriceRules appSitePriceRules = new AppSitePriceRules();
        appSitePriceRules.setSitePlaceId(appSitePlace.getId());
        appSitePriceRules.setOrgCode(appSitePlace.getOrgCode());
        appSitePriceRules.setTenantId(appSitePlace.getTenantId());
        int insert1 = appSitePriceRulesMapper.insert(appSitePriceRules);
        if (insert1 < 1) throw new JeecgBootException("无固定场价格添加失败", SC_INTERNAL_SERVER_ERROR_500);
        return Boolean.TRUE;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public Boolean updateUnfixed(AppSitePlaceUnfixedDTO unsetDTO) {
        if (null == unsetDTO.getSiteId())
            throw new JeecgBootException("商户门店不能为空", SC_INTERNAL_SERVER_ERROR_500);
        LoginUser sysUser = (LoginUser) SecurityUtils.getSubject().getPrincipal();

        AppSitePlace dbSitePlace = baseMapper.selectById(unsetDTO.getId());
        if (null == dbSitePlace) throw new JeecgBootException("数据不存在", SC_INTERNAL_SERVER_ERROR_500);
//        checkPermission(dbSitePlace,sysUser);
        AppSite site = appSiteMapper.selectById(unsetDTO.getSiteId());
        AppSitePlace appSitePlace = new AppSitePlace();
        BeanUtils.copyProperties(unsetDTO, appSitePlace);
        //固定
        appSitePlace.setType(SitePlaceTypeEnum.UNFIXED.getCode());
        appSitePlace.setOrgCode(site.getOrgCode());
        appSitePlace.setTenantId(site.getTenantId());
        int updateById = baseMapper.updateById(appSitePlace);
        if (updateById < 1) throw new JeecgBootException("无固定场编辑失败", SC_INTERNAL_SERVER_ERROR_500);
        AppSitePriceRules appSitePriceRules = new AppSitePriceRules();
        appSitePriceRules.setSitePlaceId(appSitePlace.getId());
        appSitePriceRules.setOrgCode(appSitePlace.getOrgCode());
        appSitePriceRules.setTenantId(appSitePlace.getTenantId());
        int updateById1 = appSitePriceRulesMapper.updateById(appSitePriceRules);
        if (updateById1 < 1) throw new JeecgBootException("无固定场价格编辑失败", SC_INTERNAL_SERVER_ERROR_500);
        return Boolean.TRUE;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public Boolean deleteUnfixed(String id) {
        AppSitePlace dbPlace = baseMapper.selectById(id);
        if (null == dbPlace) throw new JeecgBootException("未找到对应数据", SC_INTERNAL_SERVER_ERROR_500);
        LoginUser sysUser = (LoginUser) SecurityUtils.getSubject().getPrincipal();
//        dbPlace.setUpdateBy(sysUser.getUsername());
        int deleteById = baseMapper.deleteById(dbPlace);
        if (deleteById < 1) throw new JeecgBootException("无固定场删除失败", SC_INTERNAL_SERVER_ERROR_500);
        int deleteById1 = appSitePriceRulesMapper.delete(Wrappers.<AppSitePriceRules>lambdaQuery().eq(AppSitePriceRules::getSitePlaceId, id));
        if (deleteById1 < 1) throw new JeecgBootException("固定场价格规则删除失败", SC_INTERNAL_SERVER_ERROR_500);
        return null;
    }

    @Override
    public IPage<AppSitePlaceUnfixedDTO> queryUnfixedPage(AppSitePlaceUnfixedPageDTO dto) {
        LoginUser loginUser = (LoginUser) SecurityUtils.getSubject().getPrincipal();
        Page<AppSitePlace> page = new Page<>(dto.getPageNum(), dto.getPageSize());
        LambdaQueryWrapper<AppSitePlace> wrapper = Wrappers.<AppSitePlace>lambdaQuery().eq(AppSitePlace::getType, SitePlaceTypeEnum.UNFIXED.getCode())
                .eq(AppSitePlace::getSiteId, dto.getSiteId())
                .like(StringUtils.isNotBlank(dto.getName()), AppSitePlace::getName, dto.getName());
//                .eq(AppSitePlace::getOrgCode, loginUser.getOrgCode());

        IPage<AppSitePlace> resultPage = baseMapper.selectPage(page, wrapper);
        return resultPage.convert(record -> {
            AppSitePlaceUnfixedDTO appSitePlaceUnfixedDTO = new AppSitePlaceUnfixedDTO();
            BeanUtils.copyProperties(record, appSitePlaceUnfixedDTO);
            AppSitePriceRules appSitePriceRules = appSitePriceRulesMapper.selectOne(
                    Wrappers.<AppSitePriceRules>lambdaQuery().eq(AppSitePriceRules::getSitePlaceId, record.getId()));
            appSitePlaceUnfixedDTO.setOriginalPrice(appSitePriceRules.getOriginalPrice());
            appSitePlaceUnfixedDTO.setSellingPrice(appSitePriceRules.getSellingPrice());
            return appSitePlaceUnfixedDTO;
        });
    }

    @Override
    public AppSitePlaceUnfixedDTO queryUnfixedById(String id) {
        LoginUser loginUser = (LoginUser) SecurityUtils.getSubject().getPrincipal();
        AppSitePlace dbSitePlace = baseMapper.selectById(id);
        if (null == dbSitePlace) throw new JeecgBootException("无固定场数据不存在", SC_INTERNAL_SERVER_ERROR_500);
        AppSitePriceRules appSitePriceRules = appSitePriceRulesMapper.selectOne(
                Wrappers.<AppSitePriceRules>lambdaQuery().eq(AppSitePriceRules::getSitePlaceId, dbSitePlace.getId()));
        AppSitePlaceUnfixedDTO appSitePlaceUnfixedDTO = new AppSitePlaceUnfixedDTO();
        BeanUtils.copyProperties(dbSitePlace, appSitePlaceUnfixedDTO);
        appSitePlaceUnfixedDTO.setOriginalPrice(appSitePriceRules.getOriginalPrice());
        appSitePlaceUnfixedDTO.setSellingPrice(appSitePriceRules.getSellingPrice());

        return appSitePlaceUnfixedDTO;
    }
//包场
    @Override
    @Transactional(rollbackFor = Exception.class)
    public Boolean savePack(AppSitePlaceDTO placeDTO) {
        AppSitePlaceCuDTO placeCuDTO = placeDTO.getAppSitePlaceCuDTO();
        List<AppSiteRuleDTO> siteRuleDTOS = placeDTO.getSiteRuleDTOS();
        AppSite site = appSiteMapper.selectById(placeCuDTO.getSiteId());
        placeDTO.getSiteCategoryDOTS().forEach(item -> {
            AppCategory category = appCategoryMapper.selectById(item.getCategoryId());
            for (int i = 0; i < item.getCount(); i++) {
                AppSitePlace appSitePlace = new AppSitePlace();
                BeanUtils.copyProperties(placeCuDTO,appSitePlace);
                appSitePlace.setType(SitePlaceTypeEnum.PACKAGE.getCode());
                appSitePlace.setName(category.getName()+(i+1));
                appSitePlace.setOrgCode(site.getOrgCode());
                appSitePlace.setTenantId(site.getTenantId());
                int insert = baseMapper.insert(appSitePlace);
                if (insert < 1) throw new JeecgBootException("包场保存失败", SC_INTERNAL_SERVER_ERROR_500);
                siteRuleDTOS.stream().filter(rule -> rule.getCategoryId().equals(category.getId())).collect(Collectors.toList()).forEach(rule -> {
                    AppSitePriceRules appSitePriceRules = new AppSitePriceRules();
                    BeanUtils.copyProperties(rule,appSitePriceRules);
                    appSitePriceRules.setSitePlaceId(appSitePlace.getId());
                    appSitePriceRules.setOrgCode(appSitePlace.getOrgCode());
                    appSitePriceRules.setTenantId(appSitePlace.getTenantId());
                    int savePriceResult = appSitePriceRulesMapper.insert(appSitePriceRules);
                    if (savePriceResult < 1) throw new JeecgBootException("包场价格保存失败", SC_INTERNAL_SERVER_ERROR_500);
                });
            }

        });
        return Boolean.TRUE;
    }

    @Override
    public Boolean editPack(AppSitePlaceDTO placeDTO) {
        AppSitePlaceCuDTO placeCuDTO = placeDTO.getAppSitePlaceCuDTO();
        List<AppSiteCategoryDOT> siteCategoryDOTS = placeDTO.getSiteCategoryDOTS();
        List<AppSiteRuleDTO> siteRuleDTOS = placeDTO.getSiteRuleDTOS();

        // 按 categoryId 分组价格规则
        Map<String, List<AppSiteRuleDTO>> ruleMap = siteRuleDTOS.stream()
                .collect(Collectors.groupingBy(AppSiteRuleDTO::getCategoryId));

        AppSite site = appSiteMapper.selectById(placeCuDTO.getSiteId());
        if (site == null) {
            throw new JeecgBootException("商户门店不存在", SC_INTERNAL_SERVER_ERROR_500);
        }

        // 查询当前场地的所有包场场地
        List<AppSitePlace> existingPlaces = baseMapper.selectList(Wrappers.<AppSitePlace>lambdaQuery()
                .eq(AppSitePlace::getSiteId, site.getId())
                .eq(AppSitePlace::getType, SitePlaceTypeEnum.PACKAGE.getCode()));

        if (existingPlaces.isEmpty()) {
            throw new JeecgBootException("包场数据不存在", SC_INTERNAL_SERVER_ERROR_500);
        }

        // 用于存储需要保留的场地ID
        List<String> updatedPlaceIds = new ArrayList<>();

        // 更新或新增场地
        for (AppSiteCategoryDOT item : siteCategoryDOTS) {
            String categoryId = item.getCategoryId();
            int count = item.getCount();
            List<AppSiteRuleDTO> rules = ruleMap.getOrDefault(categoryId, Collections.emptyList());

            // 查询该分类已有的场地
            List<AppSitePlace> categoryPlaces = existingPlaces.stream()
                    .filter(p -> p.getCategoryId() != null && p.getCategoryId().equals(categoryId))
                    .sorted(Comparator.comparing(AppSitePlace::getName)) // 按名称排序以确保顺序一致
                    .collect(Collectors.toList());

            AppCategory category = appCategoryMapper.selectById(categoryId);
            if (category == null) {
                throw new JeecgBootException("分类不存在", SC_INTERNAL_SERVER_ERROR_500);
            }

            // 扩展或裁剪场地数量
            for (int i = 0; i < count; i++) {
                AppSitePlace appSitePlace;
                if (i < categoryPlaces.size()) {
                    // 更新现有场地
                    appSitePlace = categoryPlaces.get(i);
                } else {
                    // 创建新场地
                    appSitePlace = new AppSitePlace();
                    BeanUtils.copyProperties(placeCuDTO, appSitePlace);
                    appSitePlace.setType(SitePlaceTypeEnum.PACKAGE.getCode());
                    appSitePlace.setOrgCode(site.getOrgCode());
                    appSitePlace.setTenantId(site.getTenantId());
                    appSitePlace.setCategoryId(categoryId);
                }

                // 设置场地名称
                appSitePlace.setName(category.getName() + (i + 1));
                // 保存或更新场地
                if (appSitePlace.getId() == null) {
                    int insertResult = baseMapper.insert(appSitePlace);
                    if (insertResult < 1) {
                        throw new JeecgBootException("包场场地创建失败", SC_INTERNAL_SERVER_ERROR_500);
                    }
                } else {
                    int updateResult = baseMapper.updateById(appSitePlace);
                    if (updateResult < 1) {
                        throw new JeecgBootException("包场场地更新失败", SC_INTERNAL_SERVER_ERROR_500);
                    }
                }

                // 更新价格规则
                List<AppSitePriceRules> priceRules = rules.stream()
                        .map(rule -> {
                            AppSitePriceRules priceRule = new AppSitePriceRules();
                            BeanUtils.copyProperties(rule, priceRule);
                            priceRule.setSitePlaceId(appSitePlace.getId());
                            priceRule.setOrgCode(site.getOrgCode());
                            priceRule.setTenantId(site.getTenantId());
                            return priceRule;
                        })
                        .collect(Collectors.toList());

                // 删除旧的价格规则
                appSitePriceRulesMapper.delete(Wrappers.<AppSitePriceRules>lambdaQuery()
                        .eq(AppSitePriceRules::getSitePlaceId, appSitePlace.getId()));

                // 插入新的价格规则
                for (AppSitePriceRules priceRule : priceRules) {
                    int insertResult = appSitePriceRulesMapper.insert(priceRule);
                    if (insertResult < 1) {
                        throw new JeecgBootException("包场价格规则保存失败", SC_INTERNAL_SERVER_ERROR_500);
                    }
                }

                updatedPlaceIds.add(appSitePlace.getId());
            }
        }

        // 删除不再需要的场地
        for (AppSitePlace existingPlace : existingPlaces) {
            if (!updatedPlaceIds.contains(existingPlace.getId())) {
                int deleteResult = baseMapper.deleteById(existingPlace.getId());
                if (deleteResult < 1) {
                    throw new JeecgBootException("包场场地删除失败", SC_INTERNAL_SERVER_ERROR_500);
                }

                // 删除对应的价格规则
                appSitePriceRulesMapper.delete(Wrappers.<AppSitePriceRules>lambdaQuery()
                        .eq(AppSitePriceRules::getSitePlaceId, existingPlace.getId()));
            }
        }

        return Boolean.TRUE;
    }

    @Override
    public AppSitePlaceDTO queryPackById(String id) {
        AppSitePlace dbPlace = baseMapper.selectById(id);
        if (null == dbPlace) throw new JeecgBootException("包场数据不存在", SC_INTERNAL_SERVER_ERROR_500);
        AppSitePlaceCuDTO placeCuDTO = new AppSitePlaceCuDTO();
        BeanUtils.copyProperties(dbPlace, placeCuDTO);
        List<AppSiteRuleDTO> collect = appSitePriceRulesMapper.selectList(Wrappers.<AppSitePriceRules>lambdaQuery().eq(AppSitePriceRules::getSitePlaceId, id)).stream().map(rule -> {
            AppSiteRuleDTO appSiteRuleDTO = new AppSiteRuleDTO();
            BeanUtils.copyProperties(rule, appSiteRuleDTO);
            return appSiteRuleDTO;
        }).collect(Collectors.toList());
        Map<String, List<AppSiteRuleDTO>> collect1 = collect.stream().collect(Collectors.groupingBy(AppSiteRuleDTO::getCategoryId));
        List<AppSiteCategoryDOT> appSiteCategoryDOTs = collect1.entrySet().stream().map(entry -> {
            AppSiteCategoryDOT appSiteCategoryDOT = new AppSiteCategoryDOT();
            appSiteCategoryDOT.setCategoryId(entry.getKey());
            appSiteCategoryDOT.setCount(entry.getValue().size());
            return appSiteCategoryDOT;
        }).collect(Collectors.toList());

        return new AppSitePlaceDTO(placeCuDTO, collect,appSiteCategoryDOTs);
    }

    @Override
    public Boolean deletePackById(String id) {
        return null;
    }

    /**
     * 权限校验
     *
     * @param place
     * @param sysUser
     */
    private void checkPermission(AppSitePlace place, LoginUser sysUser) {
        if (!sysUser.getOrgCode().equals(place.getOrgCode()))
            throw new JeecgBootException("无权限操作", SC_INTERNAL_SERVER_ERROR_500);
    }
}
